@@ -78,6 +78,13 @@ class Client(object):
         else:
             raise ClientException(data.get('error', 'Login fail'))
 
+    def get_meta(self):
+        """
+        Returns meta user info
+
+        """
+        return self._meta
+
     def get_apps(self):
         """
         Returns dict of applications
@@ -87,7 +94,7 @@ class Client(object):
         """
         data = _request(path='/apps', method='get', api_key=self._api_key)
         if data.status_code == 200:
-            return data
+            return data.json
         else:
             raise ClientException(data.content)
 
@@ -101,7 +108,7 @@ class Client(object):
         data = _request('/apps/{0}'.format(name), method='get',
             api_key=self._api_key)
         if data.status_code == 200:
-            return data
+            return data.json
         else:
             raise ClientException(data.content)
 
@@ -115,7 +122,7 @@ class Client(object):
         data = _request('/apps/{0}/stats'.format(name), method='get',
             api_key=self._api_key)
         if data.status_code == 200:
-            return data
+            return data.json
         else:
             raise ClientException(data.content)
 
